teedoc-plugin-google-translate
===========

Google translate support for [teedoc](https://github.com/Neutree/teedoc)


## Develop


There is a config named `domain` for this plugin, by default it is `/`, means use translate resources in local.
But somtime it will be out of date, you can change it to `https://translate.google.cn/` or `https://translate.google.com/` to use google translate online.

And mannually update the files, but it is pretty hard, so we default to `https://translate.google.cn/` since update at 2023.8.16.


